<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>HiddenShortcutsDialog</name>
    <message>
        <location filename="../shortcuts.ui" line="14"/>
        <source>Hidden Shortcuts</source>
        <translation>Скрытые сочетания клавиш</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="20"/>
        <source>These hard coded shortcuts will be overridden if they are also assigned to other actions in Preferences → Shortcuts.</source>
        <translation>Эти жестко запрограммированные сочетания клавиш будут переопределены, если они также назначены другим действиям в «Настройки» → «Сочетания клавиш».</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="34"/>
        <source>Shortcut</source>
        <translation>Сочетание клавиш</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="39"/>
        <source>Action</source>
        <translation>Действие</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="44"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="47"/>
        <source>Close window or exit fullscreen mode</source>
        <translation>Закрыть окно или выйти из полноэкранного режима</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="52"/>
        <source>Right</source>
        <translation>Вправо</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="55"/>
        <location filename="../shortcuts.ui" line="63"/>
        <source>Next image</source>
        <translation>Следующее изображение</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="60"/>
        <source>Space</source>
        <translation>Пробел</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="68"/>
        <source>End</source>
        <translation>В конец (End)</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="71"/>
        <source>Last image</source>
        <translation>Последнее изображение</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="76"/>
        <source>Left</source>
        <translation>Влево</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="79"/>
        <location filename="../shortcuts.ui" line="87"/>
        <source>Previous image</source>
        <translation>Предыдущее изображение</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="84"/>
        <source>Backspace</source>
        <translation>Backspace</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="92"/>
        <source>Home</source>
        <translation>В начало (Home)</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="95"/>
        <source>First image</source>
        <translation>Первое изображение</translation>
    </message>
</context>
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../application.cpp" line="97"/>
        <source>Start in fullscreen (can be useful with tiling window managers)</source>
        <translation>Запускать в полноэкранном режиме (может быть полезно для фреймовых оконных менеджеров)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="105"/>
        <source>Take a screenshot (deprecated, please use screengrab instead)</source>
        <translation>Сделать снимок экрана (устарело, используйте вместо этого screengrab)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="114"/>
        <source>DIR</source>
        <translation>КАТАЛОГ</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="114"/>
        <source>Take a screenshot and save it to the directory without showing the GUI (deprecated, please use screengrab instead)</source>
        <translation>Сделать снимок экрана и сохранить его в указанный КАТАЛОГ без показа самой программы (устарело, используйте вместо этого screengrab)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="120"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[ФАЙЛ1, ФАЙЛ2, ...]</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgBBUpload</name>
    <message>
        <location filename="../upload/imgbbupload.cpp" line="44"/>
        <source>unknown error response</source>
        <translation>неизвестная ошибка</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgurUpload</name>
    <message>
        <location filename="../upload/imgurupload.cpp" line="47"/>
        <source>unknown error response</source>
        <translation>неизвестная ошибка</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>A simple and fast image viewer</source>
        <translation>Простой и быстрый просмотрщик изображений</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="304"/>
        <source>Copyright (C) </source>
        <translation>Авторские права (C) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>LXQt Project</source>
        <translation>Проект LXQt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>Development: </source>
        <translation>Разработка: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="310"/>
        <source>Author: </source>
        <translation>Автор: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>Open File</source>
        <translation>Открыть файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="540"/>
        <location filename="../mainwindow.cpp" line="575"/>
        <source>Image files (%1)</source>
        <translation>Файлы изображений (%1)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="553"/>
        <source>Open directory</source>
        <translation>Открыть каталог</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="574"/>
        <source>Save File</source>
        <translation>Сохранить файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="724"/>
        <location filename="../mainwindow.cpp" line="730"/>
        <location filename="../mainwindow.cpp" line="736"/>
        <location filename="../mainwindow.cpp" line="742"/>
        <location filename="../mainwindow.cpp" line="917"/>
        <source>%1/%2 Frames</source>
        <translation>%1/%2 Страниц</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="896"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (Загружается...) — Просмотрщик изображений</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="902"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (Ошибка загрузки) — Просмотрщик изображений</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="908"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) — Просмотрщик изображений</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="980"/>
        <source>[*]Image Viewer</source>
        <translation>[*]Просмотрщик изображений</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1397"/>
        <source>Thumbnails</source>
        <translation>Эскизы</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1492"/>
        <source>EXIF Data</source>
        <translation>Данные EXIF</translation>
    </message>
</context>
<context>
    <name>LxImage::MruMenu</name>
    <message>
        <location filename="../mrumenu.cpp" line="49"/>
        <source>&amp;Clear</source>
        <translation>&amp;Очистить</translation>
    </message>
</context>
<context>
    <name>LxImage::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="74"/>
        <source>Use a modifier key to clear a shortcut
in the editing mode.</source>
        <translation>Используйте клавишу-модификатор, чтобы сбросить
сочетание клавиш в режиме редактирования.</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="215"/>
        <source>Bottom</source>
        <translation>Внизу</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="216"/>
        <source>Top</source>
        <translation>Вверху</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="217"/>
        <source>Left</source>
        <translation>Слева</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="343"/>
        <source>&lt;b&gt;Warning: Ambiguous shortcut detected!&lt;/b&gt;</source>
        <translation>&lt;b&gt;Внимание: обнаружено неоднозначное сочетание клавиш!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="360"/>
        <source>&lt;b&gt;Ambiguous shortcut not accepted.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Неоднозначное сочетание клавиш не принято.&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>LxImage::SaveImageJob</name>
    <message>
        <location filename="../saveimagejob.cpp" line="54"/>
        <source>Cannot save with this image format!</source>
        <translation>Невозможно сохранить изображение в данном формате!</translation>
    </message>
</context>
<context>
    <name>LxImage::StatusBar</name>
    <message>
        <location filename="../statusbar.cpp" line="63"/>
        <source>Size:</source>
        <translation>Размер:</translation>
    </message>
    <message>
        <location filename="../statusbar.cpp" line="73"/>
        <source>Path:</source>
        <translation>Путь:</translation>
    </message>
</context>
<context>
    <name>LxImage::UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="47"/>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="48"/>
        <source>ImgBB</source>
        <translation>ImgBB</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="136"/>
        <source>Start</source>
        <translation>Запустить</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="139"/>
        <source>Stop</source>
        <translation>Остановить</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="142"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="149"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Просмотрщик изображений</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>&amp;Recent Files</source>
        <translation>&amp;Недавние файлы</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <location filename="../mainwindow.ui" line="709"/>
        <source>Annotations Toolbar</source>
        <translation>Панель примечаний</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="234"/>
        <source>&amp;About</source>
        <translation>&amp;О программе</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="251"/>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="272"/>
        <source>&amp;Save</source>
        <translation>&amp;Сохранить</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="275"/>
        <source>Ctrl+S</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="284"/>
        <source>Save &amp;As</source>
        <translation>Сохранить &amp;как</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="287"/>
        <source>Ctrl+A</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="299"/>
        <source>Ctrl+W</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="308"/>
        <source>Zoom &amp;In</source>
        <translation>При&amp;близить</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="320"/>
        <source>Zoom &amp;Out</source>
        <translation>От&amp;далить</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="323"/>
        <source>Ctrl+-</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>Копировать в &amp;буфер обмена</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <location filename="../mainwindow.ui" line="344"/>
        <source>Next File</source>
        <translation>Следующий файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="356"/>
        <location filename="../mainwindow.ui" line="359"/>
        <source>Previous File</source>
        <translation>Предыдущий файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="347"/>
        <source>PgDown</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="67"/>
        <source>Open &amp;With...</source>
        <translation>Открыть с помощью...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="126"/>
        <source>Sorting</source>
        <translation>Сортировка</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="239"/>
        <source>Hidden &amp;Shortcuts</source>
        <translation>Скрытые &amp;сочетания клавиш</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>&amp;Open…</source>
        <translation>&amp;Открыть…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="260"/>
        <source>&amp;Reload File</source>
        <translation>Пере&amp;загрузить файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="263"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="311"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="362"/>
        <source>PgUp</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="374"/>
        <source>Original Size</source>
        <translation>Исходный размер</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="377"/>
        <source>Ctrl+0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="389"/>
        <source>&amp;Fit</source>
        <translation>&amp;Заполнить</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="398"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>Пове&amp;рнуть по часовой стрелке</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="401"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="410"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>Повернуть &amp;против часовой стрелки</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="413"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="418"/>
        <source>P&amp;references</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="427"/>
        <source>&amp;Print</source>
        <translation>&amp;Печать</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="430"/>
        <source>Ctrl+P</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="439"/>
        <source>First File</source>
        <translation>Первый файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="442"/>
        <source>Home</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="451"/>
        <source>Last File</source>
        <translation>Последний файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="454"/>
        <source>End</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="463"/>
        <source>&amp;New Window</source>
        <translation>&amp;Новое окно</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="466"/>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="475"/>
        <source>Flip &amp;Horizontally</source>
        <translation>Отразить &amp;горизонтально</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="478"/>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="487"/>
        <source>Capture Screenshot</source>
        <translation>Сделать снимок экрана</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="495"/>
        <source>F&amp;ull Screen</source>
        <translation>Полный &amp;экран</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <source>F11</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="507"/>
        <source>Flip &amp;Vertically</source>
        <translation>Отразить &amp;вертикально</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="510"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="519"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>&amp;Вставить из буфера обмена</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="531"/>
        <source>&amp;Slide Show</source>
        <translation>&amp;Слайд-шоу</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="540"/>
        <source>&amp;Delete</source>
        <translation>&amp;Удалить</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="543"/>
        <source>Del</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="551"/>
        <source>Show Thumbnails</source>
        <translation>Показывать эскизы</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="554"/>
        <source>T</source>
        <translation>T</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="563"/>
        <source>File Properties</source>
        <translation>Свойства файла</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="572"/>
        <source>Open &amp;Directory</source>
        <translation>Открыть &amp;каталог</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="575"/>
        <source>Ctrl+D</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="584"/>
        <source>Upload</source>
        <translation>Отправить</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="587"/>
        <source>Upload the image</source>
        <translation>Загрузить изображение</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="590"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="598"/>
        <source>Show EXIF Data</source>
        <translation>Показать данные EXIF</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="610"/>
        <source>No Tool</source>
        <translation>Без инструмента</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="613"/>
        <source>Deselect all drawing tools</source>
        <translation>Отменить выбор инструмента рисования</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="625"/>
        <source>Draw Arrow</source>
        <translation>Нарисовать стрелку</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="628"/>
        <source>Draw an arrow</source>
        <translation>Нарисовать стрелку</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="640"/>
        <source>Draw Rectangle</source>
        <translation>Нарисовать прямоугольник</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="643"/>
        <source>Draw a hollow rectangle</source>
        <translation>Нарисовать прямоугольник (без заливки)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="655"/>
        <source>Draw Circle</source>
        <translation>Нарисовать круг</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="658"/>
        <source>Draw a hollow circle</source>
        <translation>Нарисовать окружность</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="670"/>
        <source>Draw Number</source>
        <translation>Нарисовать число</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="673"/>
        <source>Draw incrementing numbers</source>
        <translation>Нарисовать число (с увеличением счётчика)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="681"/>
        <location filename="../mainwindow.ui" line="684"/>
        <source>Menubar</source>
        <translation>Панель меню</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="687"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="695"/>
        <source>&amp;Main Toolbar</source>
        <translation>&amp;Главная панель инструментов</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="698"/>
        <source>Main Toolbar</source>
        <translation>Главная панель инструментов</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="706"/>
        <source>&amp;Annotations Toolbar</source>
        <translation>Панель &amp;примечаний</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="717"/>
        <location filename="../mainwindow.ui" line="720"/>
        <source>Show Outline</source>
        <translation>Показать контур</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="723"/>
        <source>O</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="731"/>
        <source>Copy Pa&amp;th</source>
        <translation>Ко&amp;пировать путь</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="734"/>
        <source>Copy path</source>
        <translation>Копировать путь</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="742"/>
        <location filename="../mainwindow.ui" line="745"/>
        <source>Rename</source>
        <translation>Переименовать</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="748"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="757"/>
        <source>Resize</source>
        <translation>Изменить размер</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="765"/>
        <source>&amp;By File Name</source>
        <translation>&amp;По имени файла</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="768"/>
        <source>By File Name</source>
        <translation>По имени файла</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="776"/>
        <source>By &amp;Modification Time</source>
        <translation>По дате &amp;изменения</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="779"/>
        <source>By Modification Time</source>
        <translation>По дате изменения</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="787"/>
        <source>By C&amp;reation Time</source>
        <translation>По вр&amp;емени создания</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="790"/>
        <source>By Creation Time</source>
        <translation>По дате создания</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="798"/>
        <source>By File &amp;Size</source>
        <translation>По размеру &amp;файла</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="801"/>
        <source>By File Size</source>
        <translation>По размеру файла</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="809"/>
        <source>By File &amp;Type</source>
        <translation>&amp;По типу файла</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="812"/>
        <source>By File Type</source>
        <translation>По типу файла</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="817"/>
        <source>Next Frame</source>
        <translation>Следующая страница</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="820"/>
        <source>Ctrl+Right</source>
        <translation>Ctrl+Вправо</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="825"/>
        <source>Previous Frame</source>
        <translation>Предыдущая страница</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="828"/>
        <source>Ctrl+Left</source>
        <translation>Ctrl+Влево</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="833"/>
        <source>First Frame</source>
        <translation>Первая страница</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="838"/>
        <source>Last Frame</source>
        <translation>Последняя страница</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="849"/>
        <source>Solid Background</source>
        <translation>Одноцветный фон</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>&amp;Help</source>
        <translation>&amp;Справка</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="108"/>
        <source>Go</source>
        <translation>Переход</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="122"/>
        <source>&amp;View</source>
        <translation>&amp;Вид</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="155"/>
        <source>&amp;Edit</source>
        <translation>&amp;Правка</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="179"/>
        <source>Toolbar</source>
        <translation>Панель инструментов</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Тема значков:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="53"/>
        <source>Thumbnailer file size limit:</source>
        <translation>Ограничение размера файла эскизов:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="151"/>
        <source>Normal background color:</source>
        <translation>Обычный цвет фона:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="165"/>
        <source>Fullscreen background color:</source>
        <translation>Цвет фона для режима полного экрана:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="43"/>
        <source>Maximum number of recent files:</source>
        <translation>Максимальное количество последних файлов:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="228"/>
        <source>Slide show interval (seconds):</source>
        <translation>Интервал слайд-шоу (в секундах):</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="249"/>
        <source>Show image outline by default</source>
        <translation>Показывать контур изображения по умолчанию</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="134"/>
        <source>Show annotations toolbar by default</source>
        <translation>Показывать панель примечаний по умолчанию</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="256"/>
        <source>Fit images when navigating</source>
        <translation>Подгонять изображения при навигации</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="60"/>
        <source> MiB</source>
        <translation> МиБ</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="76"/>
        <source>Thumbnail image dimensions:</source>
        <translation>Размеры изображения эскиза:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="86"/>
        <source>Use system Trash (and do not prompt)</source>
        <translation>Использовать системную корзину (и не спрашивать)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="94"/>
        <source>Window</source>
        <translation>Окно</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="103"/>
        <source>Show thumbnails dock by default</source>
        <translation>По умолчанию показывать эскизы в доке</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="113"/>
        <source>Show Exif data dock by default</source>
        <translation>Отображать панель метаданных Exif по умолчанию</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="120"/>
        <source>Show menubar by default</source>
        <translation>Отображать панель меню по умолчанию</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="127"/>
        <source>Show main toolbar by default</source>
        <translation>Отображать главную панель инструментов по умолчанию</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="142"/>
        <source>Image</source>
        <translation>Изображение</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="179"/>
        <location filename="../preferencesdialog.ui" line="190"/>
        <source>May work only with images which have valid color spaces.
Reload current image to see the effect.</source>
        <translation>Может работать только с изображениями, имеющими допустимые цветовые пространства.
Перезагрузите текущее изображение, чтобы увидеть эффект.</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="183"/>
        <source>Color space:</source>
        <translation>Цветовой охват:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="195"/>
        <source>None</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="200"/>
        <source>sRGB (supported by most monitors)</source>
        <translation>sRGB (поддерживается большинством мониторов)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="205"/>
        <source>Linear sRGB (linear gamma)</source>
        <translation>Линейный sRGB (линейная гамма)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="210"/>
        <source>Adobe RGB</source>
        <translation>Adobe RGB</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="215"/>
        <source>DisplayP3 (wide-gamut screens)</source>
        <translation>DisplayP3 (широкоформатные экраны)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="220"/>
        <source>ProPhotoRgb</source>
        <translation>ProPhotoRgb</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="242"/>
        <source>Solid background by default</source>
        <translation>Одноцветный фон по умолчанию</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="263"/>
        <source>Smooth images on zooming</source>
        <translation>Сглаживать изображения при масштабировании</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="271"/>
        <source>Shortcuts</source>
        <translation>Сочетания клавиш</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="290"/>
        <source>Action</source>
        <translation>Действие</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="295"/>
        <source>Shortcut</source>
        <translation>Сочетание клавиш</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="303"/>
        <source>Default</source>
        <translation>По умолчанию</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>Общие</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="1098"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
</context>
<context>
    <name>ResizeImageDialog</name>
    <message>
        <location filename="../resizeimagedialog.ui" line="14"/>
        <source>Resize Image</source>
        <translation>Изменение размера изображения</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="26"/>
        <source>Width</source>
        <translation>Ширина</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="33"/>
        <source>Height</source>
        <translation>Высота</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="40"/>
        <source>Current size:</source>
        <translation>Текущий размер:</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="80"/>
        <source>New size:</source>
        <translation>Новый размер:</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="93"/>
        <location filename="../resizeimagedialog.ui" line="116"/>
        <source> px</source>
        <translation> пикс</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="129"/>
        <location filename="../resizeimagedialog.ui" line="158"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="174"/>
        <source>Keep aspect ratio</source>
        <translation>Не изменять соотношение сторон</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Снимок экрана</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>Сделать снимок экрана</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>Область</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>Весь экран</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>Только активное окно</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation>Захват области экрана</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>Показывать курсор мыши</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="74"/>
        <source> sec</source>
        <translation> с</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>Задержка:</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>Показывать заголовок и обрамление окна</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.ui" line="14"/>
        <source>Upload</source>
        <translation>Отправить</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.ui" line="39"/>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
</context>
</TS>
